@@ -1,29 +1,19 @@
 #############################################################
-# File/MkTempO.pm. Written in 1999 by Travis Gummels.
+# File/MkTempO.pm. Written in 1999|2000 by Travis Gummels.
 # If you find problems with this please let me know.
 # travis@gummels.com
 #############################################################
 
 package File::MkTempO;
 
-use vars qw($VERSION @ISA @EXPORT_OK);
+use vars qw($VERSION);
 
-require Exporter;
 use FileHandle;
 use File::Spec;
 use Carp;
 use strict;
 
-@ISA=qw(Exporter);
-@EXPORT_OK=qw(mktemp mkstemp);
-
-$File::MkTemp::VERSION = '1.0.5';
-
-sub VERSION {
-   # Version of File::MkTemp
-   return $File::MkTemp::VERSION;
-}
-
+$File::MkTemp::VERSION = '1.0.6';
 
 sub new {
   my $pkg = shift;
@@ -168,7 +158,7 @@ Please send bug reports and or comments to: travis@gummels.com
 
 =head1 COPYRIGHT
 
-Copyright 1999, Travis Gummels.  All rights reserved.  This may be 
+Copyright 1999|2000 Travis Gummels.  All rights reserved.  This may be 
 used and modified however you want.  If you redistribute after making 
 modifications please note modifications you made somewhere in the
 distribution.
